@@ -2,6 +2,10 @@ package QColor;
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT);
+use overload
+    '==' => \&beq,
+    '!=' => \&bne,
+    'fallback' => 1;
 
 require Exporter;
 require DynaLoader;
@@ -16,7 +20,7 @@ require QGlobal;
 
 	     &qBlue &qGray &qGreen &qRgb &qRed);
 
-$VERSION = '1.00';
+$VERSION = '1.01';
 bootstrap QColor $VERSION;
 
 1;
@@ -69,6 +73,10 @@ qGreen,
 qRed,
 qRgb
 
+=head2 Overloaded operators
+
+!= ==
+
 =head1 DESCRIPTION
 
 Every member of QColor, except the operators, has been interfaced
