@@ -2,10 +2,6 @@ package QPointArray;
 
 use strict;
 use vars qw($VERSION @ISA);
-use overload
-    '==' => \&beq,
-    '!=' => \&bne,
-    'fallback' => 1;
 
 require DynaLoader;
 require QGlobal;
@@ -15,7 +11,7 @@ require QPoint;
 
 @ISA = qw(DynaLoader Qt::Base);
 
-$VERSION = '1.03';
+$VERSION = '1.01';
 bootstrap QPointArray $VERSION;
 
 1;
@@ -35,25 +31,15 @@ new,
 at,
 boundingRect,
 copy,
-detach,
 fill,
-isEmpty,
-isNull,
 makeArc,
 makeEllipse,
 point,
 putPoints,
 quadBezier,
-resize,
 setPoint,
 setPoints,
-size,
-translate,
-truncate
-
-=head2 Overloaded operators
-
-!= ==
+translate
 
 =head1 DESCRIPTION
 
