@@ -7,7 +7,7 @@ require DynaLoader;
 
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.01';
+$VERSION = '1.00';
 bootstrap QToolTip $VERSION;
 
 1;
@@ -23,6 +23,19 @@ QToolTip - Interface to the Qt QToolTip and QToolTipGroup classes
 
 C<use QToolTip;>
 
+=head2 QToolTip
+
+=head2 Member functions
+
+add,
+remove
+
+=head2 QToolTipGroup
+
+=head2 Member functions
+
+new
+
 =head1 DESCRIPTION
 
 What you see is what you get.
